@@ -223,8 +223,9 @@ class ActionManager(object):
                         component, delay=delay, target_state=target_state)
                     deferred.addCallback(
                         self.handle_output, cmd, component, target_state, tries + 1)
+                    error_function = self.logger.error if tries + 1 == max_tries else self.logger.warning
                     deferred.addErrback(
-                        yadtshell.twisted.report_error, self.logger.warning)
+                        yadtshell.twisted.report_error, error_function)
                     return deferred
                 self.pi.update((cmd, component), 't')
                 raise yadtshell.actions.ActionException(
@@ -254,8 +255,7 @@ class ActionManager(object):
                         except TypeError:
                             cmdline = fun()
         except ValueError, ve:
-            print(str(ve))
-            # self.logger.exception(ve)
+            self.logger.exception(ve)
             raise ve
         except Exception, ae:
             print(str(ae))
@@ -267,10 +267,11 @@ class ActionManager(object):
             raise yadtshell.actions.ActionException(
                 'problem during %s %s: could not determine the cmdline' % (cmd, component.uri), 1, None)
 
-        if isinstance(cmdline, defer.Deferred):  # TODO rename cmdline here
+        if isinstance(cmdline, defer.Deferred):
+            deferred = cmdline
             self.logger.debug('deferred returned directly')
             self.pi.update((cmd, component))
-            return cmdline
+            return deferred
 
         p = yadtshell.twisted.YadtProcessProtocol(component,
                                                   cmd,
@@ -281,7 +282,7 @@ class ActionManager(object):
         p.target_state = target_state
         p.state = yadtshell.settings.UNKNOWN
 
-        cmdline = shlex.split(cmdline.encode('ascii'))
+        cmdline = shlex.split(cmdline)
         self.logger.debug('cmd: %s' % cmdline)
         reactor.spawnProcess(p, cmdline[0], cmdline, None)
         return p.deferred
