@@ -26,6 +26,7 @@ import yaml
 import shlex
 
 from twisted.internet import reactor, task
+import twisted.internet.defer as defer
 
 from yadtshell.util import calculate_max_tries_for_interval_and_delay
 from yadtshell.helper import get_user_info
@@ -37,10 +38,10 @@ logger = logging.getLogger('components')
 
 
 class Component(object):
+
     """Abstract superclass for Host, Service, Artefacts, and some special cases thereof.
 
     Note that the `.host` attribute is always a string, not a Host instance.
-    TODO(rwill): rename it to `.hostname` or change it to a Host instance (as passed into constructor anyway).
     """
 
     def __init__(self, t, host, name):
@@ -60,12 +61,11 @@ class Component(object):
         self.fqdn = host.fqdn
         self.uri = yadtshell.uri.create(self.type, self.host, self.name)
 
-        self.host_uri = yadtshell.uri.create(yadtshell.settings.HOST, self.host)  # TODO(rwill): seems like dead code
+        self.host_uri = yadtshell.uri.create(yadtshell.settings.HOST, self.host)
 
         self.state = yadtshell.settings.UNKNOWN
         self.needs = set()
         self.needed_by = set()
-        # self.config_prefix = yadtshell.settings.TARGET_SETTINGS['name']  # TODO(rwill): dead code?
 
     def is_touched_also(self, other):
         return True
@@ -157,8 +157,6 @@ class Component(object):
 
 
 class MissingComponent(Component):
-    """TODO(rwill): What is the usecase for this? Add tests or remove it.
-    """
 
     def __init__(self, s):
         parts = yadtshell.uri.parse(s)
@@ -167,6 +165,41 @@ class MissingComponent(Component):
         self.state = yadtshell.settings.MISSING
 
 
+class ReadonlyService(Component):
+
+    def __init__(self, host, name, settings=None):
+        Component.__init__(self, yadtshell.settings.SERVICE, host, name)
+        self.state = yadtshell.settings.UNKNOWN
+
+    def immediate_status(self):
+        logger.debug("Immediate status of readonly %s (no-op)" % self.uri)
+        return defer.succeed(0)
+
+    def status(self):
+        status_command = self.remote_call(
+            'yadt-service-%s %s' % (yadtshell.settings.STATUS, self.name),
+            tag='%s_%s' % (self.name, yadtshell.settings.STATUS))
+        status_protocol = YadtProcessProtocol(self, status_command, out_log_level=logging.DEBUG)
+        cmdline = shlex.split(status_protocol.cmd)
+        reactor.spawnProcess(status_protocol, cmdline[0], cmdline, None)
+
+        return status_protocol.deferred
+
+    def start(self):
+        d = self.status()
+
+        def handle_error(failure):
+            raise RuntimeError("Cannot start readonly %s" % self.uri)
+        d.addErrback(handle_error)
+        return d
+
+    def stop(self):
+        return defer.fail(RuntimeError("Not allowed to stop readonly {0}".format(self.uri)))
+
+    def _retrieve_service_call(self, action):
+        return 'yadt-service-%s %s' % (action, self.name)
+
+
 class ComponentDict(dict):
 
     def __init__(self):
@@ -175,7 +208,7 @@ class ComponentDict(dict):
 
     def _key_(self, key):
         try:
-            return self._key_(key.uri)  # TODO(rwill): looks like the intention here is to return key.uri ??
+            return key.uri
         except AttributeError:
             return key
 
@@ -186,13 +219,13 @@ class ComponentDict(dict):
         return dict.__getitem__(self, self._key_(key))
 
     def get(self, key, default=None):
-        if self._key_(key) not in self and self._add_when_missing_:
+        key = self._key_(key)
+        if key not in self and self._add_when_missing_:
             logger.debug('missing' + key)
-            self[self._key_(key)] = MissingComponent(key)  # (rwill) why no _key_ on RHS?
-        return dict.get(self, self._key_(key), default)
+            self[key] = MissingComponent(key)
+        return dict.get(self, key, default)
 
     def __setitem__(self, key, value):
-        # logger.debug('adding ' + self._key_(key) + ' ' + getattr(value, 'state', ''))
         return dict.__setitem__(self, self._key_(key), value)
 
 
@@ -213,7 +246,7 @@ class ComponentSet(set):
         logger.debug('adding ' + key)
         if key not in self.components and check:
             logger.warning('key %(key)s not found, ignoring' % locals())
-            # logger.warning('known keys: ' + ', '.join(self.components.keys()))
+            logger.debug('known keys: ' + ', '.join(self.components.keys()))
             return None
         return self._set.add(key)
 
@@ -235,6 +268,7 @@ class ComponentSet(set):
 
 
 class AbstractHost(Component):
+
     def __init__(self, fqdn):
         # we need to set those values first, because Component.__init__ requires them on its `host` argument ;)
         self.fqdn = fqdn
@@ -248,6 +282,7 @@ class AbstractHost(Component):
 
 
 class Host(AbstractHost):
+
     """Note: `Host.name`, `Host.host` and `Host.hostname` are all the same value.
     We need `.host` and `.name` because they are part of Component, but when
     `Component.host` is renamed to Component.hostname, we will at least have
@@ -424,6 +459,7 @@ class UnreachableHost(AbstractHost):
 
 
 class Artefact(Component):
+
     """`version` is numeric
     `revision` is either 'next' or 'current'. (Use constants in yadtshell.settings!)
     """
@@ -446,6 +482,7 @@ class Service(Component):
     def __init__(self, host, name, settings=None):
         Component.__init__(self, yadtshell.settings.SERVICE, host, name)
 
+        settings = settings or {}
         self.needs_services = []
         self.needs_artefacts = []
         self.needs.add(host.uri)
@@ -469,7 +506,6 @@ class Service(Component):
             self.needs.add(yadtshell.uri.create(yadtshell.settings.ARTEFACT,
                                                 host.host,
                                                 n % locals() + "/" + yadtshell.settings.CURRENT))
-        # self.needs.add(uri.create(yadtshell.settings.HOST, host.host))
 
         self.state = yadtshell.settings.STATE_DESCRIPTIONS.get(
             settings.get('state'),
