@@ -59,7 +59,8 @@ def _show_ignored_services(services):
     for service in services:
         if hasattr(service, 'ignored'):
             ignored_services = True
-            print(render_yellow('\n%20s is ignored\n%10s' % (service, service.ignored.get('message', 'no message'))))
+            print(render_yellow('\n%20s is ignored\n%10s' %
+                  (service, service.ignored.get('message', 'no message'))))
 
     if ignored_services:
         print()  # separate ignored services from locked hosts
@@ -102,21 +103,11 @@ def info(logLevel=None, full=False, components=None, **kwargs):
 
     print()
 
-    condensed = yadtshell.helper.condense_hosts2(
-        yadtshell.helper.condense_hosts(result))
-    components_with_problems = [c for c in condensed
-                                if (c[0].startswith(yadtshell.settings.ARTEFACT) or c[0].startswith(yadtshell.settings.CONFIG))
-                                and yadtshell.util.not_up(c[1])]
-    if components_with_problems:
-        print('problems')
-        for c in components_with_problems:
-            print(yadtshell.util.render_component_state(c[0], c[1]))
-        print()
-
+    many_spaces = " " * 70  # TODO needs smarter algorithm for colored box
     for missing_component in [c for c in components.values() if isinstance(c,
                               yadtshell.components.MissingComponent)]:
-        print(render_red('\nconfig problem: missing %s\n' %
-              missing_component.uri))
+        print(render_red('%s\nconfig problem: missing %s\n%s' %
+              (many_spaces, missing_component.uri, many_spaces)))
 
     for service in services:
         if getattr(service, 'service_artefact_problem', None):
@@ -214,31 +205,87 @@ def render_highlighted_differences(*args):
     return yadtshell.settings.term.render(highlight_differences(*args))
 
 
-def calculate_info_view_settings():
-    original_hosts = yadtshell.settings.TARGET_SETTINGS['original_hosts']
+def calculate_info_view_settings(nr_of_hosts=None):
+    if not nr_of_hosts:
+        original_hosts = yadtshell.settings.TARGET_SETTINGS['original_hosts']
+
+        logger.debug("expanding hosts")
+        he = hostexpand.HostExpander.HostExpander()
+        nr_of_hosts = max([len(he.expand(hosts)) for hosts in original_hosts])
+        logger.debug("expanded hosts")
+
     try:
-        stty = Popen(['stty', 'size'], stdout=PIPE, stderr=PIPE).communicate()[0]
+        stty = Popen(
+            ['stty', 'size'], stdout=PIPE, stderr=PIPE).communicate()[0]
         cols = int(stty.split()[1])
     except:
         cols = 80
 
-    logger.debug("expanding hosts")
-    he = hostexpand.HostExpander.HostExpander()
-    max_row_length = max([len(he.expand(hosts)) for hosts in original_hosts])
-    logger.debug("expanded hosts")
-
-    width = '1col'
-
     RIGHT_MARGIN_WIDTH = 40
 
-    if max_row_length * 4 + RIGHT_MARGIN_WIDTH <= cols:
+    width = '1col'
+    if nr_of_hosts * 4 + RIGHT_MARGIN_WIDTH <= cols:
         width = '3cols'
-    if max_row_length * 10 + RIGHT_MARGIN_WIDTH <= cols:
+    if nr_of_hosts * 10 + RIGHT_MARGIN_WIDTH <= cols:
         width = 'maxcols'
 
     return ['matrix', 'color', width]
 
 
+def render_readonly_services(components):
+    ro_services = [c for c in components.itervalues()
+                   if isinstance(c, yadtshell.components.ReadonlyService)]
+    if not ro_services:
+        return
+    info_view_settings = calculate_info_view_settings(1)
+    hosts = {}
+    for ro_service in ro_services:
+        hosts.setdefault(ro_service.host, []).append(ro_service)
+    icons, _ = calc_icon_strings(info_view_settings)
+    for hostname in sorted(hosts.keys()):
+        print("  %s" % hostname)
+        print()
+        for s in hosts[hostname]:
+            print("  %s  readonly-service %s (needed by %s)" % (calc_state_string(s, icons), s.name, " ".join(s.needed_by)))
+        print()
+    print()
+
+
+def calc_state_string(service, icons):
+    if not service:
+        return icons['NA']
+    if getattr(service, 'ignored', False):
+        if service.is_up():
+            return icons['UP_IGNORED']
+        elif service.is_unknown():
+            return icons['UNKNOWN_IGNORED']
+        else:
+            return icons['DOWN_IGNORED']
+    else:
+        if service.is_up():
+            return icons['UP']
+        elif service.is_unknown():
+            return icons['UNKNOWN']
+        else:
+            return icons['DOWN']
+
+
+def calc_icon_strings(info_view_settings):
+    icons = get_icons()
+    separator = ''
+    if 'maxcols' in info_view_settings:
+        separator = '  '
+        for icon, string in icons.iteritems():
+            icons[icon] = '    %s    ' % string
+    elif '3cols' in info_view_settings:
+        separator = ' '
+        for icon, string in icons.iteritems():
+            icons[icon] = ' %s ' % string
+    if 'color' in info_view_settings:
+        icons = colorize(icons)
+    return icons, separator
+
+
 def render_services_matrix(components=None, **kwargs):
     if not components:
         components = yadtshell.util.restore_current_state()
@@ -247,6 +294,7 @@ def render_services_matrix(components=None, **kwargs):
     for hosts in yadtshell.settings.TARGET_SETTINGS['original_hosts']:
         _render_services_matrix(
             components, he.expand(hosts), info_view_settings, *kwargs)
+    render_readonly_services(components)
     render_legend(info_view_settings)
 
 
@@ -284,18 +332,7 @@ def _render_services_matrix(components, hosts, info_view_settings, enable_legend
     for rank, name in services:
         ranks[name] = rank
 
-    icons = get_icons()
-    separator = ''
-    if 'maxcols' in info_view_settings:
-        separator = '  '
-        for icon, string in icons.iteritems():
-            icons[icon] = '    %s    ' % string
-    elif '3cols' in info_view_settings:
-        separator = ' '
-        for icon, string in icons.iteritems():
-            icons[icon] = ' %s ' % string
-    if 'color' in info_view_settings:
-        icons = colorize(icons)
+    icons, separator = calc_icon_strings(info_view_settings)
     if 'maxcols' in info_view_settings:
         print('  %s' % separator.join(['%-9s' % host.host for host in hosts]))
     elif '3cols' in info_view_settings:
@@ -338,23 +375,7 @@ def _render_services_matrix(components, hosts, info_view_settings, enable_legend
             uri = yadtshell.uri.create(
                 yadtshell.settings.SERVICE, host.host, name)
             service = components.get(uri, None)
-            if service:
-                if getattr(service, 'ignored', False):
-                    if service.is_up():
-                        s.append(icons['UP_IGNORED'])
-                    elif service.is_unknown():
-                        s.append(icons['UNKNOWN_IGNORED'])
-                    else:
-                        s.append(icons['DOWN_IGNORED'])
-                else:
-                    if service.is_up():
-                        s.append(icons['UP'])
-                    elif service.is_unknown():
-                        s.append(icons['UNKNOWN'])
-                    else:
-                        s.append(icons['DOWN'])
-            else:
-                s.append(icons['NA'])
+            s.append(calc_state_string(service, icons))
             suffix = ''
             if getattr(service, 'is_frontservice', False):
                 suffix = '(frontservice)'
